# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: calibration.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'calibration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x61libration.proto\x12\x1amdrive.message.calibration\"]\n\x0bVehicleInfo\x12\r\n\x05model\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03vin\x18\x03 \x01(\t\x12\r\n\x05plate\x18\x04 \x01(\t\x12\x17\n\x0fother_unique_id\x18\x05 \x01(\t\"\xd2\n\n\x0cVehicleParam\x12!\n\x14\x66ront_edge_to_center\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12 \n\x13\x62\x61\x63k_edge_to_center\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12 \n\x13left_edge_to_center\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12!\n\x14right_edge_to_center\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x13\n\x06length\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x12\n\x05width\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x13\n\x06height\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x16\n\tmax_speed\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x1c\n\x0fmin_turn_radius\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1d\n\x10max_acceleration\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1d\n\x10max_deceleration\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1d\n\x10max_engine_pedal\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x12\x1c\n\x0fmax_brake_pedal\x18\r \x01(\x02H\x0c\x88\x01\x01\x12\x1c\n\x0fmax_steer_angle\x18\x0e \x01(\x02H\r\x88\x01\x01\x12!\n\x14max_steer_angle_rate\x18\x0f \x01(\x02H\x0e\x88\x01\x01\x12!\n\x14min_steer_angle_rate\x18\x10 \x01(\x02H\x0f\x88\x01\x01\x12\x18\n\x0bsteer_ratio\x18\x11 \x01(\x02H\x10\x88\x01\x01\x12\x17\n\nwheel_base\x18\x12 \x01(\x02H\x11\x88\x01\x01\x12!\n\x14wheel_rolling_radius\x18\x13 \x01(\x02H\x12\x88\x01\x01\x12\'\n\x1amax_abs_speed_when_stopped\x18\x14 \x01(\x02H\x13\x88\x01\x01\x12%\n\x18min_abs_speed_when_start\x18\x15 \x01(\x02H\x14\x88\x01\x01\x12\x1b\n\x0e\x62rake_deadzone\x18\x16 \x01(\x05H\x15\x88\x01\x01\x12\x1e\n\x11throttle_deadzone\x18\x17 \x01(\x05H\x16\x88\x01\x01\x12$\n\x17steer_zero_offset_angle\x18\x18 \x01(\x05H\x17\x88\x01\x01\x12\x1b\n\x0esteer_deadband\x18\x19 \x01(\x05H\x18\x88\x01\x01\x12\x1f\n\x12steer_lqr_deadband\x18\x1a \x01(\x05H\x19\x88\x01\x01\x42\x17\n\x15_front_edge_to_centerB\x16\n\x14_back_edge_to_centerB\x16\n\x14_left_edge_to_centerB\x17\n\x15_right_edge_to_centerB\t\n\x07_lengthB\x08\n\x06_widthB\t\n\x07_heightB\x0c\n\n_max_speedB\x12\n\x10_min_turn_radiusB\x13\n\x11_max_accelerationB\x13\n\x11_max_decelerationB\x13\n\x11_max_engine_pedalB\x12\n\x10_max_brake_pedalB\x12\n\x10_max_steer_angleB\x17\n\x15_max_steer_angle_rateB\x17\n\x15_min_steer_angle_rateB\x0e\n\x0c_steer_ratioB\r\n\x0b_wheel_baseB\x17\n\x15_wheel_rolling_radiusB\x1d\n\x1b_max_abs_speed_when_stoppedB\x1b\n\x19_min_abs_speed_when_startB\x11\n\x0f_brake_deadzoneB\x14\n\x12_throttle_deadzoneB\x1a\n\x18_steer_zero_offset_angleB\x11\n\x0f_steer_deadbandB\x15\n\x13_steer_lqr_deadband\"O\n\x0bTranslation\x12\x0e\n\x01x\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0e\n\x01y\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x0e\n\x01z\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\x04\n\x02_xB\x04\n\x02_yB\x04\n\x02_z\"j\n\x08Rotation\x12\x0f\n\x02qx\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02qy\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x0f\n\x02qz\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x0f\n\x02qw\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\x05\n\x03_qxB\x05\n\x03_qyB\x05\n\x03_qzB\x05\n\x03_qw\"\xd5\x01\n\nTransforms\x12\x14\n\x0csource_frame\x18\x01 \x01(\t\x12\x14\n\x0ctarget_frame\x18\x02 \x01(\t\x12\x41\n\x0btranslation\x18\x03 \x01(\x0b\x32\'.mdrive.message.calibration.TranslationH\x00\x88\x01\x01\x12;\n\x08rotation\x18\x04 \x01(\x0b\x32$.mdrive.message.calibration.RotationH\x01\x88\x01\x01\x42\x0e\n\x0c_translationB\x0b\n\t_rotation\"G\n\nExtrinsics\x12\x39\n\ttansforms\x18\x01 \x03(\x0b\x32&.mdrive.message.calibration.Transforms\"r\n\x0b\x43\x61meraModel\x12\x12\n\x05width\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06height\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\tintrinsic\x18\x03 \x03(\x01\x12\x12\n\ndistortion\x18\x04 \x03(\x01\x42\x08\n\x06_widthB\t\n\x07_height\"\xf6\x01\n\x0c\x43\x61meraParams\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x44\n\nmodel_type\x18\x02 \x01(\x0e\x32+.mdrive.message.calibration.CameraModelTypeH\x01\x88\x01\x01\x12:\n\x07pinhole\x18\x03 \x01(\x0b\x32\'.mdrive.message.calibration.CameraModelH\x00\x12:\n\x07\x66isheye\x18\x04 \x01(\x0b\x32\'.mdrive.message.calibration.CameraModelH\x00\x42\x07\n\x05modelB\r\n\x0b_model_type\"M\n\nIntrinsics\x12?\n\rcamera_params\x18\x01 \x03(\x0b\x32(.mdrive.message.calibration.CameraParams\"\x8a\x02\n\x10\x43\x61libInformation\x12=\n\x0cvehicle_info\x18\x01 \x01(\x0b\x32\'.mdrive.message.calibration.VehicleInfo\x12?\n\rvehicle_param\x18\x02 \x01(\x0b\x32(.mdrive.message.calibration.VehicleParam\x12:\n\nextrinsics\x18\x03 \x01(\x0b\x32&.mdrive.message.calibration.Extrinsics\x12:\n\nintrinsics\x18\x04 \x01(\x0b\x32&.mdrive.message.calibration.Intrinsics*+\n\x0f\x43\x61meraModelType\x12\x0b\n\x07PINHOLE\x10\x00\x12\x0b\n\x07\x46ISHEYE\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'calibration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CAMERAMODELTYPE']._serialized_start=2700
  _globals['_CAMERAMODELTYPE']._serialized_end=2743
  _globals['_VEHICLEINFO']._serialized_start=49
  _globals['_VEHICLEINFO']._serialized_end=142
  _globals['_VEHICLEPARAM']._serialized_start=145
  _globals['_VEHICLEPARAM']._serialized_end=1507
  _globals['_TRANSLATION']._serialized_start=1509
  _globals['_TRANSLATION']._serialized_end=1588
  _globals['_ROTATION']._serialized_start=1590
  _globals['_ROTATION']._serialized_end=1696
  _globals['_TRANSFORMS']._serialized_start=1699
  _globals['_TRANSFORMS']._serialized_end=1912
  _globals['_EXTRINSICS']._serialized_start=1914
  _globals['_EXTRINSICS']._serialized_end=1985
  _globals['_CAMERAMODEL']._serialized_start=1987
  _globals['_CAMERAMODEL']._serialized_end=2101
  _globals['_CAMERAPARAMS']._serialized_start=2104
  _globals['_CAMERAPARAMS']._serialized_end=2350
  _globals['_INTRINSICS']._serialized_start=2352
  _globals['_INTRINSICS']._serialized_end=2429
  _globals['_CALIBINFORMATION']._serialized_start=2432
  _globals['_CALIBINFORMATION']._serialized_end=2698
# @@protoc_insertion_point(module_scope)
